"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createGenerateSchematic = void 0;
const schematics_1 = require("@angular-devkit/schematics");
const path = require("path");
const strings_1 = require("@angular-devkit/core/src/utils/strings");
const workspace_1 = require("@schematics/angular/utility/workspace");
const core_1 = require("@angular-devkit/core");
const utils_1 = require("../../utils/utils");
function createGenerateSchematic(options) {
    return (host) => __awaiter(this, void 0, void 0, function* () {
        const workspace = yield workspace_1.getWorkspace(host);
        const project = yield utils_1.getProject(workspace, options.project);
        const parsedPath = utils_1.getParsedPath(project, options.path, options.name);
        const generatedSchematicDir = path.join(__dirname, parsedPath.path, strings_1.dasherize(options.name));
        const collectionJsonPath = path.join(__dirname, utils_1.getCollectionPath(host, project));
        const relativePathToCollectionJson = path.relative(generatedSchematicDir, collectionJsonPath);
        const templateSource = schematics_1.apply(schematics_1.url('./files'), [
            schematics_1.applyTemplates({
                name: options.name,
                collectionJsonPath: relativePathToCollectionJson.replace(/\\/g, '/'),
                camelize: core_1.strings.camelize,
                classify: core_1.strings.classify,
                dasherize: core_1.strings.dasherize,
            }),
            schematics_1.move(parsedPath.path),
        ]);
        return schematics_1.chain([schematics_1.mergeWith(templateSource), updateCollectionJson(host, project, parsedPath.path, options)]);
    });
}
exports.createGenerateSchematic = createGenerateSchematic;
function updateCollectionJson(host, project, schematicPath, options) {
    const collectionPath = utils_1.getCollectionPath(host, project);
    const collectionJsonBuffer = host.read(collectionPath);
    const schematicName = options.name;
    if (!collectionJsonBuffer) {
        throw new schematics_1.SchematicsException(`Could not read file '${collectionPath}'`);
    }
    const collectionJson = JSON.parse(collectionJsonBuffer.toString('utf8'));
    const relativePathToSchematic = path
        .relative(path.join(process.cwd(), path.dirname(collectionPath)), path.join(process.cwd(), schematicPath, schematicName, 'index'))
        .replace(/\\/g, '/');
    const updatedCollectionJson = Object.assign(Object.assign({}, collectionJson), { schematics: Object.assign(Object.assign({}, collectionJson.schematics), { [strings_1.dasherize(schematicName)]: {
                description: options.description,
                factory: `${relativePathToSchematic}#${strings_1.camelize(options.name)}`,
                schema: `${relativePathToSchematic.replace('index', 'schema.json')}`,
            } }) });
    host.overwrite(collectionPath, JSON.stringify(updatedCollectionJson, null, 2));
    return schematics_1.noop();
}
//# sourceMappingURL=index.js.map