"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.initSchematicsProject = void 0;
const schematics_1 = require("@angular-devkit/schematics");
const workspace_1 = require("@schematics/angular/utility/workspace");
const path = require("path");
const utils_1 = require("../../utils/utils");
function initSchematicsProject(options) {
    return (host) => __awaiter(this, void 0, void 0, function* () {
        const workspace = yield workspace_1.getWorkspace(host);
        const project = yield utils_1.getProject(workspace, options.project);
        const schematicsDir = path.join(project.root, 'schematics');
        const relativePathToNodeModules = path.relative(schematicsDir, path.join(process.cwd(), 'node_modules'));
        return schematics_1.chain([
            createSchematicsFiles(host, schematicsDir, relativePathToNodeModules),
            addBuilderToAngularJson(workspace, options.project),
            addSchematicsFieldsToPackageJson(host, project.root),
        ]);
    });
}
exports.initSchematicsProject = initSchematicsProject;
function createSchematicsFiles(host, targetDir, nodeModulesPath) {
    const schemaPath = path
        .join(nodeModulesPath, '@angular-devkit/schematics/collection-schema.json')
        .replace(/\\/g, '/');
    host.create(path.join(targetDir, 'collection.json'), JSON.stringify({
        $schema: schemaPath,
        schematics: {},
    }, null, 2));
    host.create(path.join(targetDir, 'migrations.json'), JSON.stringify({
        $schema: schemaPath,
        schematics: {},
    }, null, 2));
    return schematics_1.noop();
}
function addBuilderToAngularJson(workspace, projectName) {
    var _a;
    (_a = workspace.projects.get(projectName)) === null || _a === void 0 ? void 0 : _a.targets.set('build-schematics', {
        builder: 'ng-schematics-toolkit:build-schematics',
    });
    return workspace_1.updateWorkspace(workspace);
}
function addSchematicsFieldsToPackageJson(host, projectRoot) {
    const packageJsonPath = path.join(projectRoot, 'package.json');
    const packageJsonBuffer = host.read(packageJsonPath);
    if (!packageJsonBuffer) {
        throw new schematics_1.SchematicsException(`Could not find package.json in '${packageJsonPath}'`);
    }
    const packageJson = JSON.parse(packageJsonBuffer.toString('utf8'));
    const updatedPackageJson = Object.assign(Object.assign({}, packageJson), { schematics: './schematics/collection.json', 'ng-update': {
            migrations: './schematics/migrations.json',
            packageGroup: [],
        } });
    host.overwrite(packageJsonPath, JSON.stringify(updatedPackageJson, null, 2));
    return schematics_1.noop();
}
//# sourceMappingURL=index.js.map